@@ -12,6 +12,8 @@ MainWindow::MainWindow(QWidget *parent) :
 
     ui->setupUi(this);
 
+    mediaPlayer = new QMediaPlayer(this, QMediaPlayer::StreamPlayback);
+
     stationsDb.checkDB();
     stationsDb.initDB();
 
@@ -31,7 +33,7 @@ MainWindow::MainWindow(QWidget *parent) :
     nam = new QNetworkAccessManager(this);
     connect(nam, SIGNAL(finished(QNetworkReply*)), this, SLOT(onRequestFinished(QNetworkReply*)));
 
-    connect(&mediaPlayer, SIGNAL(metaDataChanged()), SLOT(getMetaData()));
+    connect(mediaPlayer, SIGNAL(metaDataChanged()), SLOT(getMetaData()));
     connectBluetoothControl();
     new TextEditAutoResizer(ui->cronologyTextEdit);
 
@@ -47,30 +49,30 @@ void MainWindow::on_playButton_clicked()
 {
     if ( ui->stationsList->currentRow() == -1 ) return;
 
-    mediaPlayer.stop();
-    mediaPlayer.setMedia(QUrl(ui->stationsList->currentItem()->toolTip()));
-    mediaPlayer.play();
+    mediaPlayer->stop();
+    mediaPlayer->setMedia(QUrl(ui->stationsList->currentItem()->toolTip()));
+    mediaPlayer->play();
     ui->titleLabel->setText(QString("<b><u>%1</b></u>").arg(ui->stationsList->currentItem()->text().split("\n").at(0)));
 }
 
 void MainWindow::getMetaData()
 {
 
-    QStringList extn_metadata = mediaPlayer.availableExtendedMetaData();
+    QStringList extn_metadata = mediaPlayer->availableExtendedMetaData();
     int count_extn = extn_metadata.count();
     QString extn_metadata_key;
     QVariant extn_metadata_value;
     for( int indx = 0; indx < count_extn; indx++ )
     {
         extn_metadata_key = extn_metadata.at(indx);
-        extn_metadata_value = mediaPlayer.extendedMetaData(extn_metadata_key);
+        extn_metadata_value = mediaPlayer->extendedMetaData(extn_metadata_key);
 
         qDebug()<<"Key is: "<<extn_metadata_key;
         qDebug()<<"Value is: "<<extn_metadata_value.toString();
 
         if ( extn_metadata_key == "title")
         {
-            QString title = mediaPlayer.extendedMetaData("title").toString();
+            QString title = mediaPlayer->extendedMetaData("title").toString();
             appendCronology(title);
 
             ui->playingLabel->setText(QString("<b>Playing:</b> %1").arg(title));
@@ -94,7 +96,7 @@ void MainWindow::getMetaData()
 
         if ( extn_metadata_key == "genre")
         {
-            QString string = mediaPlayer.extendedMetaData("genre").toString();
+            QString string = mediaPlayer->extendedMetaData("genre").toString();
 
             ui->genreLabel->setText(QString("<b>Genre:</b> %1").arg(string));
 
@@ -102,7 +104,7 @@ void MainWindow::getMetaData()
 
         if ( extn_metadata_key == "bitrate")
         {
-            QString string = mediaPlayer.extendedMetaData("bitrate").toString();
+            QString string = mediaPlayer->extendedMetaData("bitrate").toString();
 
             ui->bitrateLabel->setText(QString("<b>Bitrate:</b> %1").arg(string));
 
@@ -110,7 +112,7 @@ void MainWindow::getMetaData()
 
         if ( extn_metadata_key == "location")
         {
-            QString string = mediaPlayer.extendedMetaData("location").toString();
+            QString string = mediaPlayer->extendedMetaData("location").toString();
 
             ui->locationLabel->setText(QString("<b>Location:</b> %1").arg(string));
 
@@ -118,7 +120,7 @@ void MainWindow::getMetaData()
 
         if ( extn_metadata_key == "audio-codec")
         {
-            QString string = mediaPlayer.extendedMetaData("audio-codec").toString();
+            QString string = mediaPlayer->extendedMetaData("audio-codec").toString();
 
             ui->audiocodecLabel->setText(QString("<b>Audio codec:</b> %1").arg(string));
 
@@ -247,13 +249,13 @@ void MainWindow::setIcons()
 
 void MainWindow::on_stopButton_clicked()
 {
-    mediaPlayer.stop();
+    mediaPlayer->stop();
 }
 
 void MainWindow::on_actionAbout_triggered()
 {
     QMessageBox::about(this, tr("About"),
-                        tr("<h2>Internet Radio Player 0.0.4</h2>"
+                        tr("<h2>Internet Radio Player 0.0.6</h2>"
                            "<p>"
                            "<p>Written by Giovanni Grammatico (ggiovanni88@yahoo.it)"
                            "<p><a href=\"http://code-tinkering.blogspot.com/\">My personal blog.</a>"
@@ -352,9 +354,9 @@ void MainWindow::populateList(QStringList list)
 
 void MainWindow::on_stationsList_itemClicked(QListWidgetItem *item)
 {
-    mediaPlayer.stop();
-    mediaPlayer.setMedia(QUrl(item->toolTip()));
-    mediaPlayer.play();
+    mediaPlayer->stop();
+    mediaPlayer->setMedia(QUrl(item->toolTip()));
+    mediaPlayer->play();
     ui->titleLabel->setText(QString("<b><u>%1</b></u>").arg(item->text().split("\n").at(0)));
 }
 
@@ -399,9 +401,9 @@ void MainWindow::on_previousButton_clicked()
 
     if ( ui->stationsList->currentRow() == -1 ) return;
 
-    mediaPlayer.stop();
-    mediaPlayer.setMedia(QUrl(ui->stationsList->currentItem()->toolTip()));
-    mediaPlayer.play();
+    mediaPlayer->stop();
+    mediaPlayer->setMedia(QUrl(ui->stationsList->currentItem()->toolTip()));
+    mediaPlayer->play();
     ui->titleLabel->setText(QString("<b><u>%1</b></u>").arg(ui->stationsList->currentItem()->text().split("\n").at(0)));
 }
 
@@ -413,9 +415,9 @@ void MainWindow::on_nextButton_clicked()
 
     if ( ui->stationsList->currentRow() == -1 ) return;
 
-    mediaPlayer.stop();
-    mediaPlayer.setMedia(QUrl(ui->stationsList->currentItem()->toolTip()));
-    mediaPlayer.play();
+    mediaPlayer->stop();
+    mediaPlayer->setMedia(QUrl(ui->stationsList->currentItem()->toolTip()));
+    mediaPlayer->play();
     ui->titleLabel->setText(QString("<b><u>%1</b></u>").arg(ui->stationsList->currentItem()->text().split("\n").at(0)));
 }
 
@@ -572,12 +574,12 @@ void MainWindow::connectBluetoothControl()
 
 void MainWindow::toggleButtonPressed()
 {
-    if ( mediaPlayer.state() == QMediaPlayer::PlayingState )
+    if ( mediaPlayer->state() == QMediaPlayer::PlayingState )
     {
         on_stopButton_clicked();
     }
 
-    else if ( mediaPlayer.state() == QMediaPlayer::StoppedState )
+    else if ( mediaPlayer->state() == QMediaPlayer::StoppedState )
     {
         on_playButton_clicked();
     }
