@@ -68,7 +68,7 @@ private slots:
 
 private:
     Ui::MainWindow *ui;
-    QMediaPlayer mediaPlayer;
+    QMediaPlayer* mediaPlayer;
     QMaemo5InformationBox infoBox;
     QLabel labelBox;
     QStringList stationsList;
